# Miscellaneous

```{eval-rst}
.. currentmodule:: kaskada

.. autosummary::
   :toctree: ../apidocs/

    Timestream.cast
    Timestream.coalesce
    Timestream.else_
    Timestream.filter
    Timestream.hash
    Timestream.if_
    Timestream.lag
    Timestream.null_if
    Timestream.pipe
```